#
# spec file for package python-chartify
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
%define skip_python39 1
Name:           python-chartify
Version:        4.0.5
Release:        1.2
Summary:        Python library for plotting charts
License:        Apache-2.0
URL:            https://github.com/spotify/chartify
Source:         https://github.com/spotify/chartify/archive/%{version}.tar.gz#/chartify-%{version}.tar.gz
# PATCH-FIX-UPSTREAM chartify-pr170-pd.melt-kwarg.patch gh#spotify/chartify#170
Patch0:         chartify-pr170-pd.melt-kwarg.patch
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module Jinja2}
BuildRequires:  %{python_module Pillow >= 8.4.0}
BuildRequires:  %{python_module bokeh >= 3.0.0}
BuildRequires:  %{python_module ipykernel}
BuildRequires:  %{python_module ipython}
BuildRequires:  %{python_module pandas}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module scipy >= 1.0.0}
# ignoring https://github.com/SeleniumHQ/selenium/issues/5296
BuildRequires:  %{python_module selenium >= 3.7.0}
# /SECTION
%{?python_enable_dependency_generator}
%python_subpackages

%description
Chartify is a Python library for creating charts.

%prep
%autosetup -p1 -n chartify-%{version}
rm tox.ini
# unpin selenium (see comment above)
# unpin Jinja2 (see release notes), but keep a pinning char for the check in setup.py
sed -i \
  -e '/selenium/ s/,<=3.8.0//' \
  -e '/Jinja2/ s/<3.1.0/>1/' \
  requirements.txt

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc AUTHORS.rst README.rst
%license LICENSE
%{python_sitelib}/chartify
%{python_sitelib}/chartify-%{version}.dist-info

%changelog
* Tue Mar  5 2024 Ben Greiner <code@bnavigator.de>
- Skip python39: no longer supported since ipython 8.19
- Add chartify-pr170-pd.melt-kwarg.patch gh#spotify/chartify#170
- Build PEP517 wheel, clean some obsolete pinning edits
* Fri Nov 10 2023 Dirk Müller <dmueller@suse.com>
- update to 4.0.5:
  * Relaxed scipy and pandas version requirements to allow
    verions 2.x
  * Documentation build fix
  * Pin tornado requirement to reduce vulnerability
  * Require jupyter_bokeh to enable html output
* Sun Jun 11 2023 Dirk Müller <dmueller@suse.com>
- update to 4.0.2:
  * Fix categorical_order_by check for scatter plot
  * Fix categorical_order_by check for _construct_source
  * Refactor category sorting in _construct_source
  * Add tests for categorical_order_by
  * Fix scatter plot tests that used line plots
  * Updated version requirement of pillow to avoid bug
  * Dropped support for python 3.6 and 3.7
- unpin pandas to allow 2.x
* Sun Jun 11 2023 Dirk Müller <dmueller@suse.com>
- update to 3.1.0:
  * Added Boxplot Chart including example in examples notebook
* Wed Jan  4 2023 Dirk Müller <dmueller@suse.com>
- update to 3.0.5:
  * Fixed a few errors in example and tutorial notebooks
  * Fixed a typo in requirements.txt
* Tue Nov 22 2022 Ben Greiner <code@bnavigator.de>
- Update to 3.0.4
  * This update is a maintanaince release with no new features and
    mainly behind the scenes updates
  * Limit versions of bokeh, Jinja, and importlib-metadata to fix
    build error. This is only necessary for python 3.6 it seems.
  * Updated required versions of pytest and coverage
  * Update setup.py (#135)
  * Update options.py (#133)
  * Change ChromeDriver link to avoid deprecated site (#134)
  * Added test case and fix from PR #127
  * Eliminate a number of deprecation warnings
- Use python dependency generator
  * Adjust requirements.txt accordingly, unpin where needed
* Fri Feb 12 2021 Ben Greiner <code@bnavigator.de>
- Update to 3.0.3
  * Fix loading of color, color palette and styles configuration
    with PyYaml >= 5.2
- Change in 3.0.2
  * Support pyyaml 5.2+
- Skip python36 build in TW because python36-scipy is no more
  (NEP 29)
* Wed Jul  8 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 3.0.1
  * Reduce dependencies by switching from Jupyter to IPython.
  * Updated Python to 3.6+ and Pandas to 1.0+ (Thanks @tomasaschan!)
  * Updated Bokeh to 2.0+
  * Removed colour dependency to fix setup errors.
* Mon Apr  6 2020 Tomáš Chvátal <tchvatal@suse.com>
- Disable one test that fails due to numpy update
* Tue Dec  3 2019 Todd R <toddrme2178@gmail.com>
- initial version
